@@ -6,12 +6,14 @@ import redis
 from multiprocessing.dummy import Pool as ThreadPool
 
 from redis.client import Lock
+from redis.sentinel import Sentinel
 
-from .hashring import HashRing
-from .pipeline import Pipeline
-from .helpers import format_config
 from .commands import SHARD_METHODS
 from ._compat import basestring, iteritems
+from .hashring import HashRing
+from .helpers import format_servers
+from .pipeline import Pipeline
+from .sentinel import SentinelRedis
 
 _findhash = re.compile('.*\{(.*)\}.*', re.I)
 
@@ -33,20 +35,24 @@ def list_or_args(keys, args):
 
 class RedisShardAPI(object):
 
-    def __init__(self, settings=None):
+    def __init__(self, servers, hash_method='crc32', sentinel=None):
         self.nodes = []
         self.connections = {}
         self.pool = None
-        settings = format_config(settings)
-        for server_config in settings:
+        servers = format_servers(servers)
+        if sentinel:
+            sentinel = Sentinel(sentinel['hosts'], socket_timeout=sentinel.get('socket_timeout', 1))
+        for server_config in servers:
             name = server_config.pop('name')
-            conn = redis.Redis(**server_config)
             if name in self.connections:
                 raise ValueError("server's name config must be unique")
+            if sentinel:
+                self.connections[name] = SentinelRedis(sentinel, name)
+            else:
+                self.connections[name] = redis.Redis(**server_config)
             server_config['name'] = name
-            self.connections[name] = conn
             self.nodes.append(name)
-        self.ring = HashRing(self.nodes)
+        self.ring = HashRing(self.nodes, hash_method=hash_method)
 
     def get_server_name(self, key):
         g = _findhash.match(key)
@@ -187,3 +193,11 @@ class RedisShardAPI(object):
         if not all(x == shas[0] for x in shas):
             raise ValueError('not all server returned same sha')
         return shas[0]
+
+    def haskey(self, key):
+        server_name = self.get_server_name(key)
+        return key in self.connections[server_name]
+
+    def __delitem__(self, key):
+        server_name = self.get_server_name(key)
+        del self.connections[server_name][key]
